#!/bin/bash
set -e

echo "### Downloading and installing Homebrew ###"
echo | /usr/bin/ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"

echo "##### Installing OpenPose #####"
echo "### Prepare Homebrew #####"
brew update
brew cask install cmake
echo "### Download OpenPose repository #####"
git clone https://github.com/CMU-Perceptual-Computing-Lab/openpose.git
git clone https://github.com/marcschulder/openpose.git
echo "### Installing OpenPose dependencies ###"
brew install openblas
brew install -vd snappy leveldb gflags glog szip lmdb
brew tap homebrew/science
brew install hdf5 opencv
brew install protobuf boost
brew install cmake
brew install viennacl

echo "### Apply OSX patches ###"
cd openpose/3rdparty/caffe
git apply ../../scripts/osx/mac_opencl_patch.txt
cd ../..
git apply ../openPose_caffe.patch

echo "### Build OpenPose ###"
mkdir build
cmake -S . -B build

cd build/
make -j`nproc`

echo "### Test OpenPose ###"
./build/examples/openpose/openpose.bin --video examples/media/video.avi --face --hand
